@@ -70,8 +70,8 @@ class Spec:
             if issubclass(cls, Node) and cls is not Node:
                 node = {}
                 inst = cls()
-                node.id = inst.id
-                node.name = inst.name
+                node.id = inst.name
+                node.name = inst.title
                 node.icon = inst.icon
                 node.color = inst.color
                 node.editor = inst.editor
